@@ -15,7 +15,7 @@ environment.DeferImport('django.db.connection')
 environment.DeferImport('django.db.models')
 
 
-available           = False   # xyzzy - set to True in boot sequence
+available           = False   # xyzzy - need a better way of setting/detecting this
 
 
 
